@@ -1,5 +1,5 @@
-# ZestyParser 0.5.0 -- Parses in Python zestily
-# Copyright (C) 2006 Adam Atlas
+# ZestyParser 0.6.0 -- Parses in Python zestily
+# Copyright (C) 2006-2007 Adam Atlas
 # 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -15,5 +15,16 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
+'''
+@version: 0.6.0
+@author: Adam Atlas
+@copyright: Copyright 2006-2007 Adam Atlas. Released under the terms of the GNU General Public License.
+@contact: adam@atlas.st
+
+@group Parsing: Parser,Tokens
+@group Utilities: AHT
+'''
+
 from Parser import *
-from Tokens import *
\ No newline at end of file
+from Tokens import *
+from AHT import *
\ No newline at end of file
